@@ -1,7 +1,7 @@
 """Import all plugins for them to autoregister
 """
 
-from . import dnb
+from . import litas_esis
 from . import swedbank
 from . import maxibps
 from . import danske
